==> flatnuke_2.7.orig.tar.gz: flatnuke-2.7/languages/admin/it.php <==
<?php
/*
 * @author Marco Segato <segatom@users.sourceforge.net>
 */

//2.7
define ("_FNCC_FNOPTIONS",	"Opzioni Flatnuke");
define ("_FNCC_SERVERINFOS",	"Informazioni<br />server");
define ("_FNCC_GENERALCONF",	"Configurazione<br />generale");
define ("_FNCC_FILEMANAGER",	"File<br />manager");
define ("_FNCC_MANAGEFN",	"Gestione sito");
define ("_FNCC_NEWS",	"Gestione<br />notizie");
define ("_FNCC_NEWSBYUSERS",	"Notizie<br />segnalate");
define ("_FNCC_MOTD",	"Modifica<br>benvenuto");
define ("_FNCC_POLL",	"Gestione<br>sondaggio");
define ("_FNCC_USERS",	"Gestione utenti");
define ("_FNCC_USERSLIST",	"Elenco<br />utenti");
define ("_FNCC_ADDUSER",	"Nuovo<br />utente");
define ("_FNCC_SECURITY",	"Gestione sicurezza");
define ("_FNCC_BACKUPS",	"Backup<br />del sito");
define ("_FNCC_LOGS",	"Gestione<br />logs");
define ("_FNCC_BLACKLISTS",	"Gestione<br />blacklists");
define ("_FNCC_THEME",	"Opzioni tema");
define ("_FNCC_THEMESTRUCTURE",	"Struttura<br />tema");
define ("_FNCC_THEMESTYLE",	"Stile<br />tema");
define ("_FNCC_CSSTHEME",	"CSS<br />tema");
define ("_FNCC_CSSFORUM",	"CSS<br />forum");
define ("_FNCC_NOGDLIB",	"Estensione non installata (<a href='http://www.libgd.org/FAQ_PHP' target='_blank'>?</a>)");
define ("_FNCC_SERVERINFO",	"Informazioni sul Server");
define ("_FNCC_SITEURL",	"Indirizzo dell'Host: ");
define ("_FNCC_OS",	"Sistema operativo: ");
define ("_FNCC_WEBSERVER",	"Server web: ");
define ("_FNCC_PHP",	"Versione di PHP: ");
define ("_FNCC_GDLIB",	"Versione librerie GD: ");
define ("_FNCC_FLATNUKE",	"Versione di Flatnuke: ");
define ("_FNCC_FNUNKNOWN",	"sconosciuta");
define ("_FNCC_SERVERSPACE",	"Spazio disponibile sul server: ");
define ("_FNCC_SITESPACE",	"Dimensioni del sito corrente: ");
define ("_FNCC_MYINFOS",	"Informazioni su di me");
define ("_FNCC_IP",	"Indirizzo IP: ");
define ("_FNCC_USERAGENT",	"Browser: ");
define ("_FNCC_DESGENERALCONF",	"Configurazione generale di Flatnuke");
define ("_FNCC_DESMOTD",	"Modifica il messaggio di benvenuto");
define ("_FNCC_DESNEWS",	"Gestione notizie del portale");
define ("_FNCC_DESNEWSBYUSERS",	"Gestione notizie segnalate");
define ("_FNCC_DESPOLL",	"Modifica il sondaggio corrente");
define ("_FNCC_DESUSERSLIST",	"Elenco degli utenti iscritti");
define ("_FNCC_DESADDUSER",	"Aggiungi un nuovo utente al sito");
define ("_FNCC_DESBACKUPS",	"Gestione backup del portale");
define ("_FNCC_DESLOGS",	"Gestione log di Flatnuke");
define ("_FNCC_DESBLACKLISTS",	"Gestione blacklist di Flatnuke");
define ("_FNCC_DESTHEMESTRUCTURE",	"Modifica la struttura del tema corrente");
define ("_FNCC_DESTHEMESTYLE",	"Modifica lo stile del tema corrente");
define ("_FNCC_DESCSSTHEME",	"Modifica il foglio di stile CSS del tema corrente");
define ("_FNCC_DESCSSFORUM",	"Modifica il foglio di stile CSS del forum");
define ("_FNCC_ONLYADMIN",	"Impossibile accedere all'opzione selezionata");
define ("_FNCC_DESONLYADMIN",	"Non puoi visualizzare la pagina scelta, sezione riservata all'amministratore.");
define ("_FNCC_CONFSITENAME",	"Titolo del sito (max. 100 caratteri):");
define ("_FNCC_CONFSITEDESCRIPTION",	"Descrizione del sito (max. 500 caratteri):");
define ("_FNCC_CONFKEYWORDS",	"Lista di parole chiave che descrivono il contenuto del sito (max. 1500 caratteri):");
define ("_FNCC_CONFTHEME",	"Tema del sito:");
define ("_FNCC_CONFNEWSPP",	"Numero di notizie stampate per pagina (max. 999):");
define ("_FNCC_CONFADMIN",	"Nome dell'amministratore del sito (max. 100 caratteri):");
define ("_FNCC_CONFADMINMAIL",	"Indirizzo e-mail dell'amministratore del sito (max. 100 caratteri):");
define ("_FNCC_CONFLANG",	"Lingua utilizzata nel sito:");
define ("_FNCC_CONFREGUSER",	"Permetti ai visitatori di registrarsi al sito:");
define ("_FNCC_CONFGUESTNEWS",	"Permetti ai visitatori di proporre news da pubblicare nel sito:");
define ("_FNCC_CONFGUESTCOMMENT",	"Permetti ai visitatori di commentare le news del sito:");
define ("_FNCC_CONFREMEMBERLOGIN",	"Permetti agli utenti di memorizzare i cookie con i dati dell'autenticazione:");
define ("_FNCC_CONFMAINTENANCE",	"Imposta il sito in stato di manutenzione (solo l'amministratore pu&ograve; eseguire il login):");
define ("_FNCC_CONFHOMESECTION",	"Sezione da visualizzare in homepage (lasciare vuoto per stampare le news):");
define ("_FNCC_CONFTOPICPERPAGE",	"Numero di argomenti del forum per ogni pagina (max = 999):");
define ("_FNCC_CONFPOSTPERPAGE",	"Numero di messaggi del forum per ogni pagina (max = 999):");
define ("_FNCC_CONFMEMBERPERPAGE",	"Numero di utenti del forum per ogni pagina (max = 999):");
define ("_FNCC_CONFFORUMMODERATORS",	"Elenco dei moderatori del forum (separare i nomi con una virgola, max 500 caratteri):");
define ("_FNCC_WARNINGDOC",	"ATTENZIONE: leggere bene la documentazione prima di modificare questo file!");
define ("_FNCC_WARNINGRIGHTS",	"Modifica impossibile: controlla i permessi di scrittura del file!");
define ("_FNCC_WARNINGNOFILE",	"File non presente, controllare l'installazione di Flatnuke!");
define ("_FNCC_CHANGEDATE",	"Data di modifica");
define ("_FNCC_BACKUPNEWS",	"Esegui il backup delle news");
define ("_FNCC_BACKUPUSERS",	"Esegui il backup degli utenti");
define ("_FNCC_BACKUPMISC",	"Esegui il backup della directory");
define ("_FNCC_BACKUPSECT",	"Esegui il backup delle sezioni");
define ("_FNCC_BACKUPFORUM",	"Esegui il backup del forum");
define ("_FNCC_BACKUPSITE",	"Esegui il backup di tutto il sito");
define ("_FNCC_DELBACKUP",	"Elimina i files dei backup temporanei");
define ("_FNCC_SAVE",	"Salva");
define ("_FNCC_LOGLIST",	"Elenco log di sistema");
define ("_FNCC_CLEANLOG",	"Pulisci log");
define ("_FNCC_MANAGEBLACKLISTS",	"Elenco blacklist di sistema");
define ("_FNCC_YES",	"S&igrave;");
define ("_FNCC_NO",	"No");
define ("_FNCC_USERSTOACTIVATE",	"Profili da<br />attivare");
define ("_FNCC_WAITINGUSERS",	"Profili in attesa di attivazione");
define ("_FNCC_NOUSERSTOACTIVATE", "Non ci sono profili utente in attesa di attivazione!");
define ("_FNCC_REGMAIL", "E-mail reg.");
define ("_FNCC_REGMAILDES", "Modifica l'indirizzo e-mail");
define ("_FNCC_REGCODE", "Codice reg.");
define ("_FNCC_REGCODEDES", "Rispedisci il codice di attivazione");
define ("_FNCC_ACTIVATE", "Attiva");

?>

==> flatnuke_2.7.2.orig.tar.gz: flatnuke-2.7.2/languages/admin/it.php <==
<?php
/*
 * @author Marco Segato <segatom@users.sourceforge.net>
 */

//2.7
define ("_FNCC_FNOPTIONS",	"Opzioni Flatnuke");
define ("_FNCC_SERVERINFOS",	"Informazioni<br />server");
define ("_FNCC_GENERALCONF",	"Configurazione<br />generale");
define ("_FNCC_FILEMANAGER",	"Gestione<br />file");
define ("_FNCC_MANAGEFN",	"Gestione sito");
define ("_FNCC_NEWS",	"Gestione<br />notizie");
define ("_FNCC_NEWSBYUSERS",	"Notizie<br />segnalate");
define ("_FNCC_MOTD",	"Modifica<br>benvenuto");
define ("_FNCC_POLL",	"Gestione<br>sondaggio");
define ("_FNCC_USERS",	"Gestione utenti");
define ("_FNCC_USERSLIST",	"Elenco<br />utenti");
define ("_FNCC_ADDUSER",	"Nuovo<br />utente");
define ("_FNCC_SECURITY",	"Gestione sicurezza");
define ("_FNCC_BACKUPS",	"Backup<br />del sito");
define ("_FNCC_LOGS",	"Gestione<br />logs");
define ("_FNCC_BLACKLISTS",	"Gestione<br />blacklists");
define ("_FNCC_THEME",	"Opzioni tema");
define ("_FNCC_THEMESTRUCTURE",	"Struttura<br />tema");
define ("_FNCC_THEMESTYLE",	"Stile<br />tema");
define ("_FNCC_CSSTHEME",	"CSS<br />tema");
define ("_FNCC_CSSFORUM",	"CSS<br />forum");
define ("_FNCC_NOGDLIB",	"Estensione non installata (<a href='http://www.libgd.org/FAQ_PHP' target='_blank'>?</a>)");
define ("_FNCC_SERVERINFO",	"Informazioni sul Server");
define ("_FNCC_SITEURL",	"Indirizzo dell'Host: ");
define ("_FNCC_OS",	"Sistema operativo: ");
define ("_FNCC_WEBSERVER",	"Server web: ");
define ("_FNCC_PHP",	"Versione di PHP: ");
define ("_FNCC_GDLIB",	"Versione librerie GD: ");
define ("_FNCC_FLATNUKE",	"Versione di Flatnuke: ");
define ("_FNCC_FNUNKNOWN",	"sconosciuta");
define ("_FNCC_SERVERSPACE",	"Spazio disponibile sul server: ");
define ("_FNCC_SITESPACE",	"Dimensioni del sito corrente: ");
define ("_FNCC_MYINFOS",	"Informazioni su di me");
define ("_FNCC_IP",	"Indirizzo IP: ");
define ("_FNCC_USERAGENT",	"Browser: ");
define ("_FNCC_DESGENERALCONF",	"Configurazione generale di Flatnuke");
define ("_FNCC_DESMOTD",	"Modifica il messaggio di benvenuto");
define ("_FNCC_DESNEWS",	"Gestione notizie del portale");
define ("_FNCC_DESNEWSBYUSERS",	"Gestione notizie segnalate");
define ("_FNCC_DESPOLL",	"Modifica il sondaggio corrente");
define ("_FNCC_DESUSERSLIST",	"Elenco degli utenti iscritti");
define ("_FNCC_DESADDUSER",	"Aggiungi un nuovo utente al sito");
define ("_FNCC_DESBACKUPS",	"Gestione backup del portale");
define ("_FNCC_DESLOGS",	"Gestione log di Flatnuke");
define ("_FNCC_DESBLACKLISTS",	"Gestione blacklist di Flatnuke");
define ("_FNCC_DESTHEMESTRUCTURE",	"Modifica la struttura del tema corrente");
define ("_FNCC_DESTHEMESTYLE",	"Modifica lo stile del tema corrente");
define ("_FNCC_DESCSSTHEME",	"Modifica il foglio di stile CSS del tema corrente");
define ("_FNCC_DESCSSFORUM",	"Modifica il foglio di stile CSS del forum");
define ("_FNCC_ONLYADMIN",	"Impossibile accedere all'opzione selezionata");
define ("_FNCC_DESONLYADMIN",	"Non puoi visualizzare la pagina scelta, sezione riservata all'amministratore.");
define ("_FNCC_CONFSITENAME",	"Titolo del sito (max. 100 caratteri):");
define ("_FNCC_CONFSITEDESCRIPTION",	"Descrizione del sito (max. 500 caratteri):");
define ("_FNCC_CONFKEYWORDS",	"Lista di parole chiave che descrivono il contenuto del sito (max. 1500 caratteri):");
define ("_FNCC_CONFTHEME",	"Tema del sito:");
define ("_FNCC_CONFNEWSPP",	"Numero di notizie stampate per pagina (max. 999):");
define ("_FNCC_CONFADMIN",	"Nome dell'amministratore del sito (max. 100 caratteri):");
define ("_FNCC_CONFADMINMAIL",	"Indirizzo e-mail dell'amministratore del sito (max. 100 caratteri):");
define ("_FNCC_CONFLANG",	"Lingua utilizzata nel sito:");
define ("_FNCC_CONFREGUSER",	"Permetti ai visitatori di registrarsi al sito:");
define ("_FNCC_CONFGUESTNEWS",	"Permetti ai visitatori di proporre news da pubblicare nel sito:");
define ("_FNCC_CONFGUESTCOMMENT",	"Permetti ai visitatori di commentare le news del sito:");
define ("_FNCC_CONFREMEMBERLOGIN",	"Permetti agli utenti di memorizzare i cookie con i dati dell'autenticazione:");
define ("_FNCC_CONFMAINTENANCE",	"Imposta il sito in stato di manutenzione (solo l'amministratore pu&ograve; eseguire il login):");
define ("_FNCC_CONFHOMESECTION",	"Sezione da visualizzare in homepage (lasciare vuoto per stampare le news):");
define ("_FNCC_CONFTOPICPERPAGE",	"Numero di argomenti del forum per ogni pagina (max = 999):");
define ("_FNCC_CONFPOSTPERPAGE",	"Numero di messaggi del forum per ogni pagina (max = 999):");
define ("_FNCC_CONFMEMBERPERPAGE",	"Numero di utenti del forum per ogni pagina (max = 999):");
define ("_FNCC_CONFFORUMMODERATORS",	"Elenco dei moderatori del forum (separare i nomi con una virgola, max 500 caratteri):");
define ("_FNCC_WARNINGDOC",	"ATTENZIONE: leggere bene la documentazione prima di modificare questo file!");
define ("_FNCC_WARNINGRIGHTS",	"Modifica impossibile: controlla i permessi di scrittura del file!");
define ("_FNCC_WARNINGNOFILE",	"File non presente, controllare l'installazione di Flatnuke!");
define ("_FNCC_CHANGEDATE",	"Data di modifica");
define ("_FNCC_BACKUPNEWS",	"Esegui il backup delle news");
define ("_FNCC_BACKUPUSERS",	"Esegui il backup degli utenti");
define ("_FNCC_BACKUPMISC",	"Esegui il backup della directory");
define ("_FNCC_BACKUPSECT",	"Esegui il backup delle sezioni");
define ("_FNCC_BACKUPFORUM",	"Esegui il backup del forum");
define ("_FNCC_BACKUPSITE",	"Esegui il backup di tutto il sito");
define ("_FNCC_DELBACKUP",	"Elimina i files dei backup temporanei");
define ("_FNCC_SAVE",	"Salva");
define ("_FNCC_LOGLIST",	"Elenco log di sistema");
define ("_FNCC_CLEANLOG",	"Pulisci log");
define ("_FNCC_MANAGEBLACKLISTS",	"Elenco blacklist di sistema");
define ("_FNCC_YES",	"S&igrave;");
define ("_FNCC_NO",	"No");
define ("_FNCC_USERSTOACTIVATE",	"Profili da<br />attivare");
define ("_FNCC_WAITINGUSERS",	"Profili in attesa di attivazione");
define ("_FNCC_NOUSERSTOACTIVATE", "Non ci sono profili utente in attesa di attivazione!");
define ("_FNCC_REGMAIL", "E-mail reg.");
define ("_FNCC_REGMAILDES", "Modifica l'indirizzo e-mail");
define ("_FNCC_REGCODE", "Codice reg.");
define ("_FNCC_REGCODEDES", "Rispedisci il codice di attivazione");
define ("_FNCC_ACTIVATE", "Attiva");
define ("_FNCC_NEWSEDITOR", "Scegli l'editor per le news:");

//2.7.1
define ("_FNCC_DOWNCONF",	"Gestione<br />download");
define ("_FNCC_DESDOWNCONF",	"Gestione sezione download");
define ("_FNCC_FDPEXTENSIONS",	"Elenco delle estensioni riconosciute (lista separata da virgole):");
define ("_FNCC_FDPMAXFILESIZE",	"Dimensione massima in byte dei file da pubblicare (1Mb = 1.000.000 byte):");
define ("_FNCC_FDPICONSTYLE",	"Tema delle icone da utilizzare:");
define ("_FNCC_FDPNEWFILETIME",	"Numero di ore per cui un file &egrave considerato come recente (192h = 1 settimana):");
define ("_FNCC_FDPAUTOMD5",	"Calcola automaticamente la codifica MD5 del file caricato:");
define ("_FNCC_FDPAUTOSHA1",	"Calcola automaticamente la codifica SHA-1 del file caricato:");
define ("_FNCC_FDPSHOWUPLOADER",	"Visualizza il nome dell'utente che ha caricato il file:");
define ("_FNCC_FDPGPG",	"Estensione della firma GPG di un file:");
define ("_FNCC_FDPSCREENSHOTS",	"Estensione delle immagini di anteprima dei file:");
define ("_FNCC_FDPADMINS",	"Elenco degli utenti che possono amministrare la sezione (lista separata da virgole):");
define ("_FNCC_FDPADMINOPTOK",	"Abilita le opzioni di amministrazione via web:");
define ("_FNCC_FDPSHOWLINK",	"Visualizza il link supplementare \"Download\" per ogni file:");
define ("_FNCC_FDPFILELIST",	"Visualizza l'elenco dei file nella pagina di riepilogo:");
define ("_FNCC_FDPSUMMARY",	"Visualizza un sommario all'inizio di ogni sezione di download:");
define ("_FNCC_FDPVOTE",	"Abilita la votazione dei file:");
define ("_FNCC_FDPMAXUSERSIZE",	"Dimensione massima in byte dei file che gli utenti possono pubblicare (1Mb = 1.000.000 byte):");
define ("_FNCC_FDPNUMWAITING",	"Numero massimo di file in attesa di pubblicazione:");
define ("_FNCC_FDPFILEWAITING",	"Nome della lista dei file in attesa di pubblicazione (NON MODIFICARE):");
define ("_FNCC_FDPBLACKLIST",	"Elenco degli utenti che non possono pubblicare file (lista separata da virgole):");
define ("_FNCC_FDPMINLEVEL",	"Livello minimo degli utenti che possono pubblicare un file:");

?>
